@@ -102,6 +102,16 @@ OC.L10N.register(
     "{actor} removed circle {circle}" : "{actor} tirèt lo cercle {circle}",
     "You removed circle {circle}" : "Avètz tirat lo cercle {circle}",
     "An administrator removed circle {circle}" : "Un administrator tirèt lo cercle {circle}",
+    "{actor} promoted {user} to moderator" : "{actor} faguèt passar {user} moderator",
+    "You promoted {user} to moderator" : "Avètz fach passar {user} moderator",
+    "{actor} promoted you to moderator" : "{actor} vos faguèt passar moderator",
+    "An administrator promoted you to moderator" : "Un administrator vos faguèt passar moderator",
+    "An administrator promoted {user} to moderator" : "Un administrator faguèt passar {user} moderator",
+    "{actor} demoted {user} from moderator" : "{actor} retrogradèt {user} de l’estat de moderator",
+    "You demoted {user} from moderator" : "Avètz retrogradat {user} de l’estat de moderator",
+    "{actor} demoted you from moderator" : "{actor} vos retrogradèt de l’estat de moderator",
+    "An administrator demoted you from moderator" : "Un administrator vos retrogradèt de l’estat de moderator",
+    "An administrator demoted {user} from moderator" : "Un administrator retrogradèt {user} de l’estat de moderator",
     "{actor} shared a file which is no longer available" : "{actor} partegèt un fichièr qu’es pas pus disponible",
     "You shared a file which is no longer available" : "Partegèretz un fichièr qu'es pas pus disponible",
     "The shared location is malformed" : "L’emplaçament partejat es mal format",
@@ -127,10 +137,16 @@ OC.L10N.register(
     "You missed a call from {user}" : "Avètz mancat una sonada de {user}",
     "You tried to call {user}" : "Avètz ensajat de sonar {user}",
     "_Call with %n guest (Duration {duration})_::_Call with %n guests (Duration {duration})_" : ["Sonada amb %n convidat (Durada {duration})","Sonada amb %n convidats (Durada {duration})"],
+    "_{actor} ended the call with %n guest (Duration {duration})_::_{actor} ended the call with %n guests (Duration {duration})_" : ["{actor} acabèt la sonada amb %n convidat (Durada {duration})","{actor} acabèt la sonada amb %n convidats (Durada {duration})"],
     "Call with {user1} and {user2} (Duration {duration})" : "Sonada amb {user1} e {user2} (Durada {duration})",
+    "{actor} ended the call with {user1} (Duration {duration})" : "{actor} acabèt la sonada amb {user1} (Durada {duration})",
+    "{actor} ended the call with {user1} and {user2} (Duration {duration})" : "{actor} acabèt la sonada amb {user1} e {user2} (Durada {duration})",
     "Call with {user1}, {user2} and {user3} (Duration {duration})" : "Sonada amb {user1}, {user2} e {user3} (Durada {duration})",
+    "{actor} ended the call with {user1}, {user2} and {user3} (Duration {duration})" : "{actor} acabèt la sonada amb {user1}, {user2} e {user3} (Durada {duration})",
     "Call with {user1}, {user2}, {user3} and {user4} (Duration {duration})" : "Sonada amb {user1}, {user2}, {user3} e {user4} (Durada {duration})",
+    "{actor} ended the call with {user1}, {user2}, {user3} and {user4} (Duration {duration})" : "{actor} acabèt la sonada amb {user1}, {user2}, {user3} e {user4} (Durada {duration})",
     "Call with {user1}, {user2}, {user3}, {user4} and {user5} (Duration {duration})" : "Sonada amb {user1}, {user2}, {user3}, {user4} e {user5} (Durada {duration})",
+    "{actor} ended the call with {user1}, {user2}, {user3}, {user4} and {user5} (Duration {duration})" : "{actor} acabèt la sonada amb {user1}, {user2}, {user3}, {user4} {user5} (Durada {duration})",
     "Talk to %s" : "Parlar a %s",
     "File is not shared, or shared but not with the user" : "Fichièr pas partejat, o partejat mas pas a l’utilizaire",
     "No account available to delete." : "Cap de compte pas disponible per la supression.",
@@ -161,10 +177,14 @@ OC.L10N.register(
     "{user} sent you a private message" : "{user} vos a enviat un messatge privat",
     "{user} sent a message in conversation {call}" : "{user} a enviat un messatge dins la conversacion {call}",
     "A deleted user sent a message in conversation {call}" : "Un utilizaire suprimit vos envièt un messatge dins la conversacion {call}",
+    "{guest} (guest) sent a message in conversation {call}" : "{guest} (convidat) mandèt un messatge dins la conversacion {call}",
     "A guest sent a message in conversation {call}" : "Un convidat a enviat un messatge dins la conversacion {call}",
     "{user} replied to your private message" : "{user} a respondut a vòstre messatge privat",
     "{user} replied to your message in conversation {call}" : "{user} a respondut a vòstre messatge dins la conversacion {call}",
     "A deleted user replied to your message in conversation {call}" : "Un utilizaire suprimit a respondut a vòstre messatge dins la conversacion {call}",
+    "{guest} (guest) replied to your message in conversation {call}" : "{guest} (convidat) respondèt a vòstre messatge dins la conversacion {call}",
+    "A guest replied to your message in conversation {call}" : "Un convidat respondèt a vòstre messatge dins la conversacion {call}",
+    "{user} mentioned you in a private conversation" : "{user} vos mencionèt dins una conversacion privada",
     "{user} mentioned you in conversation {call}" : "{user} vos a mencionat dins la conversacion {call}",
     "A deleted user mentioned you in conversation {call}" : "Un utilizaire suprimit vos a mencionat dins la conversacion {call}",
     "{guest} (guest) mentioned you in conversation {call}" : "{guest} (convidat) vos a mencionat dins la conversacion {call}",
@@ -179,8 +199,13 @@ OC.L10N.register(
     "A group call has started in {call}" : "Una sonada de grop a començat dins {call}",
     "You missed a group call in {call}" : "Avètz mancat una sonada de grop dins {call}",
     "{email} is requesting the password to access {file}" : "{email} demanda l’accès al fichièr {file}",
+    "{email} tried to request the password to access {file}" : "{email} ensagèt de demandar lo senhal per accedir a {file}",
     "Someone is requesting the password to access {file}" : "Qualqu’un demanda lo senhal per accedir a {file}",
+    "Someone tried to request the password to access {file}" : "Qualqu’un ensagèt de demandar lo senhal per accedir a {file}",
     "Open settings" : "Dobrir los paramètres",
+    "The hosted signaling server is now configured and will be used." : "Lo servidor de senhalament albergat es ara configurat e serà utilizat.",
+    "Contact via Talk" : "Contactar via Talk",
+    "Open Talk" : "Dobrir la conversacion",
     "Conversations" : "Discussions",
     "Messages" : "Messatges",
     "{user}" : "{user}",
@@ -512,6 +537,7 @@ OC.L10N.register(
     "OK: Running version: {version}" : "OK : execucion de la version : {version}",
     "Error: Cannot connect to server" : "Error : connexion impossibla al servidor",
     "Error: Server did not respond with proper JSON" : "Error: lo servidor a pas respondut amb un JSON corrèct",
+    "Error: Server needs to be updated to be compatible with this version of Talk" : "Error  : lo servidor requerís una actualizacion per èsser compatible amb aquesta version de Talk",
     "Error: Server responded with: {error}" : "Error : lo servidor a respondut : {error}",
     "Error: Unknown error occurred" : "Error : una error desconeguda s'es produsida",
     "Saved" : "Enregistrat",
@@ -594,13 +620,19 @@ OC.L10N.register(
     "Drop your files to upload" : "Depausatz los fichièrs d’enviar",
     "Call in progress" : "Sonada en cors",
     "Favorite" : "Favorit",
+    "All permissions" : "Totas las permissions",
+    "Restricted" : "Restrencha",
+    "Advanced permissions" : "Permissions avançadas",
+    "Edit permissions" : "Modificar las autorizacions",
+    "Default permissions modified for {conversationName}" : "Permissions per defaut modificadas per {conversationName}",
+    "Could not modify default permissions for {conversationName}" : "Las permissions per defaut se podiá pas modificar {conversationName}",
     "Conversation settings" : "Paramètres de conversacion",
     "Description" : "Descripcion",
     "Enter a description for this conversation" : "Picatz una descripcion per aquesta conversacion",
-    "Chat notifications" : "Notificacions de chat",
     "Device check" : "Verificacion de periferic",
     "Always show the device preview screen before joining a call in this conversation." : "Totjorn mostrar l’ecran d’apercebut abans de rejónher una sonada d’aquesta conversacion.",
     "Guests access" : "Accès convidat",
+    "Participants permissions" : "Permissions dels participants",
     "Meeting settings" : "Paramètres de reünion",
     "Matterbridge" : "Matterbridge",
     "Danger zone" : "Zòna perilhosa",
@@ -796,6 +828,13 @@ OC.L10N.register(
     "This conversation has been locked" : "Aquesta conversacion foguèt clavada",
     "Write message, @ to mention someone …" : "Escriure un messatge, @ per mencionar qualqu’un…",
     "Invalid path selected" : "Camin seleccionat invalid",
+    "Skip the lobby" : "Passar la sala d’espèra",
+    "Enable the microphone" : "Activar lo microfòn",
+    "Enable the camera" : "Activar la camèra",
+    "Share the screen" : "Partejar l’ecran",
+    "Update permissions" : "Actualizar las autorizacions",
+    "Updating permissions" : "Actualizacion de las permissions",
+    "Edit default permissions for participants in <strong>{conversationName}</strong>" : "Modificar las permissions per defaut dels participants dins <strong>{conversationName}</strong>",
     "Disable lobby" : "Desactivar la sala d’espèra",
     "moderator" : "moderator",
     "bot" : "robòt",
@@ -855,6 +894,7 @@ OC.L10N.register(
     "Failed to save sounds setting" : "Cargament impossible del paramètre de son",
     "Sounds setting saved" : "Paramètres de son enregistrats",
     "Error while saving sounds setting" : "Error en enregistrant lo paramètre de son",
+    "End meeting for all" : "Acabar la conferéncia per totes",
     "Start call" : "Començar sonada",
     "Nextcloud Talk was updated, you need to reload the page before you can start or join a call." : "Nextcloud Talk foguèt mes a jorn, vos cal recargar la pagina abans de poder començar o participar a una sonada.",
     "You will be able to join the call only after a moderator starts it." : "Poiretz sonque participar a la sonada un còp qu'un moderator l'aja començada.",
@@ -864,6 +904,7 @@ OC.L10N.register(
     "Mute others" : "Copar lo son dels autres",
     "Exit fullscreen (F)" : "Quitar plen ecran (F)",
     "Fullscreen (F)" : "Plen ecran (F)",
+    "Speaker view" : "Vista parlaire",
     "Grid view" : "Vista en grasilha",
     "You have new unread messages in the chat." : "Avètz un messatge pas legit al chat.",
     "You have been mentioned in the chat." : "Qualqu’un vos a mencionat al chat.",
@@ -902,6 +943,8 @@ OC.L10N.register(
     "Sending signaling message has failed." : "Lo mandadís de messatge de senhalament a pas reüssit.",
     "Lost connection to signaling server. Trying to reconnect." : "Connexion perduda al servidor de senhalament. Ensag de reconnexion.",
     "Lost connection to signaling server. Try to reload the page manually." : "Connexion perduda al servidor de senhalament. Ensajatz de recargar la pagina manualament.",
+    "Establishing signaling connection is taking longer than expected …" : "L’establiment de la connexion de senhalizacion pren mai de temps que previst…",
+    "Failed to establish signaling connection. Retrying …" : "Fracàs de l’establiment de la connexion de senhalizacion. Novèl ensag…",
     "Failed to establish signaling connection. Something might be wrong in the signaling server configuration" : "Fracàs de l’establiment de la connexion de senhalizacion. Quicòm pòt èsser maridament configurat costat servidor.",
     "Default" : "Defaut",
     "Microphone {number}" : "Microfòn {number}",
@@ -928,6 +971,8 @@ OC.L10N.register(
     "New in Talk 8" : "Nòu dins Talk 8",
     "New in Talk 9" : "Nòu dins Talk 9",
     "New in Talk 10" : "Nòu dins Talk 10",
+    "{actor} updated the Matterbridge configuration." : "{actor} metèt a jorn la configuracion de Matterbridge",
+    "You updated the Matterbridge configuration." : "Avètz mes a jorn la configuracion de Matterbridge",
     "You removed the Matterbridge configuration." : "Avètz tirada la configuracion de Matterbridge.",
     "{user} wants to talk with you" : "{user} vòl vos parlar",
     "E-mail of the user" : "E-mail de l’utilizaire",
@@ -945,6 +990,7 @@ OC.L10N.register(
     "Your internet connection or computer are busy and other participants might be unable to understand and see your screen. To improve the situation try to disable your screenshare." : "Vòstra connexion Internet o vòstre ordenador es ocupat poiriá arribar que los demai participants vos comprengan o vejan pas. Per melhorar la situacion ensajatz de desactivar lo partiment d’ecran.",
     "This conversation is read only" : "La conversacion es en lectura sola",
     "Conversation, " : "Conversacion, ",
+    "Chat notifications" : "Notificacions de chat",
     "Allow guests to join via link " : "Permetre als convidats de rejónher via ligam",
     "You are currently waiting in the lobby. This meeting is scheduled for {startTime}" : "Sètz a esperar dins la sala d’espèra. Aquesta conferéncia es planificada per {startTime}",
     "Microphone" : "Microfòn",
@@ -962,6 +1008,7 @@ OC.L10N.register(
     "Fullscreen (f)" : "Ecran complèt (f)",
     "The browser you're using is not fully supported by Nextcloud Talk. Please use the latest version of Mozilla Firefox, Microsoft Edge, Google Chrome or Apple Safari." : "Lo navegador qu’utilizatz es pas complètament pres en cargar per Nextcloud Talk. Mercés d’utilizar la darrièra version de Mozilla Firefox, Microsoft Edge, Google Chrome o Apple Safari.",
     "Error while uploading file" : "Error en enviant lo fichièr",
+    "Use speaker view" : "Utilizar la vista de parlaire",
     "{actor} set the description to \"%1$s\"" : "{actor} a definit la descripcion « %1$s »",
     "You set the description to \"%1$s\"" : "Avètz definit la descripcion « %1$s »",
     "An administrator set the description to \"%1$s\"" : "Un administrator a definit la descripcion « %1$s »",
