@@ -95,6 +95,8 @@ class Capabilities implements IPublicCapability {
 				'signaling-v3',
 				'publishing-permissions',
 				'clear-history',
+				'direct-mention-flag',
+				'notification-calls',
 			],
 			'config' => [
 				'attachments' => [
