@@ -133,7 +133,7 @@ class ChatManager {
 		$comment->setMessage($message, self::MAX_CHAT_LENGTH);
 		$comment->setCreationDateTime($creationDateTime);
 		if ($referenceId !== null) {
-			$referenceId = trim(substr($referenceId, 0, 40));
+			$referenceId = trim(substr($referenceId, 0, 64));
 			if ($referenceId !== '') {
 				$comment->setReferenceId($referenceId);
 			}
@@ -220,7 +220,7 @@ class ChatManager {
 			$comment->setParentId($replyTo->getId());
 		}
 
-		$referenceId = trim(substr($referenceId, 0, 40));
+		$referenceId = trim(substr($referenceId, 0, 64));
 		if ($referenceId !== '') {
 			$comment->setReferenceId($referenceId);
 		}
@@ -239,13 +239,17 @@ class ChatManager {
 			}
 
 			$alreadyNotifiedUsers = [];
+			$usersDirectlyMentioned = $this->notifier->getMentionedUserIds($comment);
 			if ($replyTo instanceof IComment) {
 				$alreadyNotifiedUsers = $this->notifier->notifyReplyToAuthor($chat, $comment, $replyTo);
+				if ($replyTo->getActorType() === Attendee::ACTOR_USERS) {
+					$usersDirectlyMentioned[] = $replyTo->getActorId();
+				}
 			}
 
 			$alreadyNotifiedUsers = $this->notifier->notifyMentionedUsers($chat, $comment, $alreadyNotifiedUsers);
 			if (!empty($alreadyNotifiedUsers)) {
-				$this->participantService->markUsersAsMentioned($chat, $alreadyNotifiedUsers, (int) $comment->getId());
+				$this->participantService->markUsersAsMentioned($chat, $alreadyNotifiedUsers, (int) $comment->getId(), $usersDirectlyMentioned);
 			}
 
 			// User was not mentioned, send a normal notification
@@ -527,4 +531,37 @@ class ChatManager {
 	public function searchForObjects(string $search,  array $objectIds, string $verb = '', int $offset = 0, int $limit = 50): array {
 		return $this->commentsManager->searchForObjects($search, 'chat', $objectIds, $verb, $offset, $limit);
 	}
+
+	public function addConversationNotify(array $results, string $search, Room $room, Participant $participant): array {
+		if ($room->getType() === Room::TYPE_ONE_TO_ONE) {
+			return $results;
+		}
+		$attendee = $participant->getAttendee();
+		if ($attendee->getActorType() === Attendee::ACTOR_USERS) {
+			$roomDisplayName = $room->getDisplayName($attendee->getActorId());
+		} else {
+			$roomDisplayName = $room->getDisplayName('');
+		}
+		if ($search === '' || $this->searchIsPartOfConversationNameOrAtAll($search, $roomDisplayName)) {
+			array_unshift($results, [
+				'id' => 'all',
+				'label' => $roomDisplayName,
+				'source' => 'calls'
+			]);
+		}
+		return $results;
+	}
+
+	private function searchIsPartOfConversationNameOrAtAll(string $search, string $roomDisplayName): bool {
+		if (stripos($roomDisplayName, $search) === 0) {
+			return true;
+		}
+		if (strpos('all', $search) === 0) {
+			return true;
+		}
+		if (strpos('here', $search) === 0) {
+			return true;
+		}
+		return false;
+	}
 }
