@@ -32,6 +32,7 @@ use OCA\Talk\Chat\ChatManager;
 use OCA\Talk\Chat\MessageParser;
 use OCA\Talk\Config;
 use OCA\Talk\Events\UserEvent;
+use OCA\Talk\Exceptions\ForbiddenException;
 use OCA\Talk\Exceptions\InvalidPasswordException;
 use OCA\Talk\Exceptions\ParticipantNotFoundException;
 use OCA\Talk\Exceptions\RoomNotFoundException;
@@ -54,16 +55,18 @@ use OCP\AppFramework\Http\DataResponse;
 use OCP\AppFramework\Utility\ITimeFactory;
 use OCP\Comments\IComment;
 use OCP\EventDispatcher\IEventDispatcher;
+use OCP\Federation\ICloudIdManager;
+use OCP\IConfig;
+use OCP\IGroup;
+use OCP\IGroupManager;
 use OCP\IL10N;
 use OCP\IRequest;
 use OCP\IUser;
 use OCP\IUserManager;
-use OCP\IGroup;
-use OCP\IGroupManager;
-use OCP\IConfig;
 use OCP\User\Events\UserLiveStatusEvent;
 use OCP\UserStatus\IManager as IUserStatusManager;
 use OCP\UserStatus\IUserStatus;
+use Psr\Log\LoggerInterface;
 
 class RoomController extends AEnvironmentAwareController {
 	public const EVENT_BEFORE_ROOMS_GET = self::class . '::preGetRooms';
@@ -80,6 +83,8 @@ class RoomController extends AEnvironmentAwareController {
 	protected $groupManager;
 	/** @var Manager */
 	protected $manager;
+	/** @var ICloudIdManager */
+	protected $cloudIdManager;
 	/** @var RoomService */
 	protected $roomService;
 	/** @var ParticipantService */
@@ -104,6 +109,8 @@ class RoomController extends AEnvironmentAwareController {
 	protected $config;
 	/** @var Config */
 	protected $talkConfig;
+	/** @var LoggerInterface */
+	protected $logger;
 
 	/** @var array */
 	protected $commonReadMessages = [];
@@ -127,7 +134,9 @@ class RoomController extends AEnvironmentAwareController {
 								ITimeFactory $timeFactory,
 								IL10N $l10n,
 								IConfig $config,
-								Config $talkConfig) {
+								Config $talkConfig,
+								ICloudIdManager $cloudIdManager,
+								LoggerInterface $logger) {
 		parent::__construct($appName, $request);
 		$this->session = $session;
 		$this->appManager = $appManager;
@@ -147,6 +156,8 @@ class RoomController extends AEnvironmentAwareController {
 		$this->l10n = $l10n;
 		$this->config = $config;
 		$this->talkConfig = $talkConfig;
+		$this->cloudIdManager = $cloudIdManager;
+		$this->logger = $logger;
 	}
 
 	protected function getTalkHashHeader(): array {
@@ -213,7 +224,7 @@ class RoomController extends AEnvironmentAwareController {
 			&& $includeStatus
 			&& $this->appManager->isEnabledForUser('user_status')) {
 			$userIds = array_filter(array_map(function (Room $room) {
-				if ($room->getType() === Room::ONE_TO_ONE_CALL) {
+				if ($room->getType() === Room::TYPE_ONE_TO_ONE) {
 					$participants = json_decode($room->getName(), true);
 					foreach ($participants as $participant) {
 						if ($participant !== $this->userId) {
@@ -347,24 +358,24 @@ class RoomController extends AEnvironmentAwareController {
 	/**
 	 * @param Room $room
 	 * @param Participant|null $currentParticipant
-	 * @param array $statuses
+	 * @param array|null $statuses
 	 * @param bool $isSIPBridgeRequest
 	 * @return array
 	 * @throws RoomNotFoundException
 	 */
-	protected function formatRoom(Room $room, ?Participant $currentParticipant, array $statuses = [], bool $isSIPBridgeRequest = false): array {
+	protected function formatRoom(Room $room, ?Participant $currentParticipant, ?array $statuses = null, bool $isSIPBridgeRequest = false): array {
 		return $this->formatRoomV4($room, $currentParticipant, $statuses, $isSIPBridgeRequest);
 	}
 
 	/**
 	 * @param Room $room
 	 * @param Participant|null $currentParticipant
-	 * @param array $statuses
+	 * @param array|null $statuses
 	 * @param bool $isSIPBridgeRequest
 	 * @return array
 	 * @throws RoomNotFoundException
 	 */
-	protected function formatRoomV4(Room $room, ?Participant $currentParticipant, array $statuses, bool $isSIPBridgeRequest): array {
+	protected function formatRoomV4(Room $room, ?Participant $currentParticipant, ?array $statuses, bool $isSIPBridgeRequest): array {
 		$roomData = [
 			'id' => $room->getId(),
 			'token' => $room->getToken(),
@@ -383,10 +394,12 @@ class RoomController extends AEnvironmentAwareController {
 			'lastReadMessage' => 0,
 			'unreadMessages' => 0,
 			'unreadMention' => false,
+			'unreadMentionDirect' => false,
 			'isFavorite' => false,
 			'canLeaveConversation' => false,
 			'canDeleteConversation' => false,
 			'notificationLevel' => Participant::NOTIFY_NEVER,
+			'notificationCalls' => Participant::NOTIFY_CALLS_OFF,
 			'lobbyState' => Webinary::LOBBY_NONE,
 			'lobbyTimer' => 0,
 			'lastPing' => 0,
@@ -396,7 +409,10 @@ class RoomController extends AEnvironmentAwareController {
 			'actorType' => '',
 			'actorId' => '',
 			'attendeeId' => 0,
-			'publishingPermissions' => Attendee::PUBLISHING_PERMISSIONS_NONE,
+			'permissions' => Attendee::PERMISSIONS_CUSTOM,
+			'attendeePermissions' => Attendee::PERMISSIONS_CUSTOM,
+			'callPermissions' => Attendee::PERMISSIONS_CUSTOM,
+			'defaultPermissions' => Attendee::PERMISSIONS_CUSTOM,
 			'canEnableSIP' => false,
 			'attendeePin' => '',
 			'description' => '',
@@ -457,12 +473,16 @@ class RoomController extends AEnvironmentAwareController {
 			'callFlag' => $room->getCallFlag(),
 			'isFavorite' => $attendee->isFavorite(),
 			'notificationLevel' => $attendee->getNotificationLevel(),
+			'notificationCalls' => $attendee->getNotificationCalls(),
 			'lobbyState' => $room->getLobbyState(),
 			'lobbyTimer' => $lobbyTimer,
 			'actorType' => $attendee->getActorType(),
 			'actorId' => $attendee->getActorId(),
 			'attendeeId' => $attendee->getId(),
-			'publishingPermissions' => $attendee->getPublishingPermissions(),
+			'permissions' => $currentParticipant->getPermissions(),
+			'attendeePermissions' => $attendee->getPermissions(),
+			'callPermissions' => $room->getCallPermissions(),
+			'defaultPermissions' => $room->getDefaultPermissions(),
 			'description' => $room->getDescription(),
 			'listable' => $room->getListable(),
 		]);
@@ -497,7 +517,7 @@ class RoomController extends AEnvironmentAwareController {
 		if ($roomData['notificationLevel'] === Participant::NOTIFY_DEFAULT) {
 			if ($currentParticipant->isGuest()) {
 				$roomData['notificationLevel'] = Participant::NOTIFY_NEVER;
-			} elseif ($room->getType() === Room::ONE_TO_ONE_CALL) {
+			} elseif ($room->getType() === Room::TYPE_ONE_TO_ONE) {
 				$roomData['notificationLevel'] = Participant::NOTIFY_ALWAYS;
 			} else {
 				$adminSetting = (int) $this->config->getAppValue('spreed', 'default_group_notification', Participant::NOTIFY_DEFAULT);
@@ -510,7 +530,8 @@ class RoomController extends AEnvironmentAwareController {
 		}
 
 		if ($room->getLobbyState() === Webinary::LOBBY_NON_MODERATORS &&
-			!$currentParticipant->hasModeratorPermissions()) {
+			!$currentParticipant->hasModeratorPermissions() &&
+			!($currentParticipant->getPermissions() & Attendee::PERMISSIONS_LOBBY_IGNORE)) {
 			// No participants and chat messages for users in the lobby.
 			$roomData['hasCall'] = false;
 			return $roomData;
@@ -540,28 +561,36 @@ class RoomController extends AEnvironmentAwareController {
 				}
 
 				$lastMention = $attendee->getLastMentionMessage();
+				$lastMentionDirect = $attendee->getLastMentionDirect();
 				$roomData['unreadMention'] = $lastMention !== 0 && $lastReadMessage < $lastMention;
+				$roomData['unreadMentionDirect'] = $lastMentionDirect !== 0 && $lastReadMessage < $lastMentionDirect;
 				$roomData['lastReadMessage'] = $lastReadMessage;
 
-				$roomData['canDeleteConversation'] = $room->getType() !== Room::ONE_TO_ONE_CALL
+				$roomData['canDeleteConversation'] = $room->getType() !== Room::TYPE_ONE_TO_ONE
 					&& $currentParticipant->hasModeratorPermissions(false);
 				$roomData['canLeaveConversation'] = true;
 				$roomData['canEnableSIP'] =
 					$this->talkConfig->isSIPConfigured()
 					&& !preg_match(Room::SIP_INCOMPATIBLE_REGEX, $room->getToken())
-					&& ($room->getType() === Room::GROUP_CALL || $room->getType() === Room::PUBLIC_CALL)
+					&& ($room->getType() === Room::TYPE_GROUP || $room->getType() === Room::TYPE_PUBLIC)
 					&& $currentParticipant->hasModeratorPermissions(false)
 					&& $this->talkConfig->canUserEnableSIP($currentUser);
 			}
 		}
 
 		// FIXME This should not be done, but currently all the clients use it to get the avatar of the user …
-		if ($room->getType() === Room::ONE_TO_ONE_CALL) {
+		if ($room->getType() === Room::TYPE_ONE_TO_ONE) {
 			$participants = json_decode($room->getName(), true);
 			foreach ($participants as $participant) {
 				if ($participant !== $attendee->getActorId()) {
 					$roomData['name'] = $participant;
 
+					if ($statuses === null
+						&& $this->userId !== null
+						&& $this->appManager->isEnabledForUser('user_status')) {
+						$statuses = $this->statusManager->getUserStatuses([$participant]);
+					}
+
 					if (isset($statuses[$participant])) {
 						$roomData['status'] = $statuses[$participant]->getStatus();
 						$roomData['statusIcon'] = $statuses[$participant]->getIcon();
@@ -616,7 +645,7 @@ class RoomController extends AEnvironmentAwareController {
 	 * @return DataResponse
 	 */
 	public function createRoom(int $roomType, string $invite = '', string $roomName = '', string $source = ''): DataResponse {
-		if ($roomType !== Room::ONE_TO_ONE_CALL) {
+		if ($roomType !== Room::TYPE_ONE_TO_ONE) {
 			/** @var IUser $user */
 			$user = $this->userManager->get($this->userId);
 
@@ -626,9 +655,9 @@ class RoomController extends AEnvironmentAwareController {
 		}
 
 		switch ($roomType) {
-			case Room::ONE_TO_ONE_CALL:
+			case Room::TYPE_ONE_TO_ONE:
 				return $this->createOneToOneRoom($invite);
-			case Room::GROUP_CALL:
+			case Room::TYPE_GROUP:
 				if ($invite === '') {
 					return $this->createEmptyRoom($roomName, false);
 				}
@@ -636,7 +665,7 @@ class RoomController extends AEnvironmentAwareController {
 					return $this->createCircleRoom($invite);
 				}
 				return $this->createGroupRoom($invite);
-			case Room::PUBLIC_CALL:
+			case Room::TYPE_PUBLIC:
 				return $this->createEmptyRoom($roomName);
 		}
 
@@ -713,7 +742,7 @@ class RoomController extends AEnvironmentAwareController {
 
 		// Create the room
 		$name = $this->roomService->prepareConversationName($targetGroup->getDisplayName());
-		$room = $this->roomService->createConversation(Room::GROUP_CALL, $name, $currentUser);
+		$room = $this->roomService->createConversation(Room::TYPE_GROUP, $name, $currentUser);
 		$this->participantService->addGroup($room, $targetGroup);
 
 		return new DataResponse($this->formatRoom($room, $room->getParticipant($currentUser->getUID(), false)), Http::STATUS_CREATED);
@@ -745,7 +774,7 @@ class RoomController extends AEnvironmentAwareController {
 
 		// Create the room
 		$name = $this->roomService->prepareConversationName($circle->getName());
-		$room = $this->roomService->createConversation(Room::GROUP_CALL, $name, $currentUser);
+		$room = $this->roomService->createConversation(Room::TYPE_GROUP, $name, $currentUser);
 		$this->participantService->addCircle($room, $circle);
 
 		return new DataResponse($this->formatRoom($room, $room->getParticipant($currentUser->getUID(), false)), Http::STATUS_CREATED);
@@ -764,7 +793,7 @@ class RoomController extends AEnvironmentAwareController {
 			return new DataResponse([], Http::STATUS_NOT_FOUND);
 		}
 
-		$roomType = $public ? Room::PUBLIC_CALL : Room::GROUP_CALL;
+		$roomType = $public ? Room::TYPE_PUBLIC : Room::TYPE_GROUP;
 
 		// Create the room
 		try {
@@ -815,6 +844,23 @@ class RoomController extends AEnvironmentAwareController {
 		return new DataResponse();
 	}
 
+	/**
+	 * @NoAdminRequired
+	 * @RequireLoggedInParticipant
+	 *
+	 * @param int $level
+	 * @return DataResponse
+	 */
+	public function setNotificationCalls(int $level): DataResponse {
+		try {
+			$this->participantService->updateNotificationCalls($this->participant, $level);
+		} catch (\InvalidArgumentException $e) {
+			return new DataResponse([], Http::STATUS_BAD_REQUEST);
+		}
+
+		return new DataResponse();
+	}
+
 	/**
 	 * @PublicPage
 	 * @RequireModeratorParticipant
@@ -823,7 +869,7 @@ class RoomController extends AEnvironmentAwareController {
 	 * @return DataResponse
 	 */
 	public function renameRoom(string $roomName): DataResponse {
-		if ($this->room->getType() === Room::ONE_TO_ONE_CALL) {
+		if ($this->room->getType() === Room::TYPE_ONE_TO_ONE) {
 			return new DataResponse([], Http::STATUS_BAD_REQUEST);
 		}
 
@@ -845,7 +891,7 @@ class RoomController extends AEnvironmentAwareController {
 	 * @return DataResponse
 	 */
 	public function setDescription(string $description): DataResponse {
-		if ($this->room->getType() === Room::ONE_TO_ONE_CALL) {
+		if ($this->room->getType() === Room::TYPE_ONE_TO_ONE) {
 			return new DataResponse([], Http::STATUS_BAD_REQUEST);
 		}
 
@@ -865,7 +911,7 @@ class RoomController extends AEnvironmentAwareController {
 	 * @return DataResponse
 	 */
 	public function deleteRoom(): DataResponse {
-		if ($this->room->getType() === Room::ONE_TO_ONE_CALL) {
+		if ($this->room->getType() === Room::TYPE_ONE_TO_ONE) {
 			return new DataResponse([], Http::STATUS_BAD_REQUEST);
 		}
 
@@ -943,7 +989,8 @@ class RoomController extends AEnvironmentAwareController {
 				'actorId' => $participant->getAttendee()->getActorId(),
 				'actorType' => $participant->getAttendee()->getActorType(),
 				'displayName' => $participant->getAttendee()->getActorId(),
-				'publishingPermissions' => $participant->getAttendee()->getPublishingPermissions(),
+				'permissions' => $participant->getPermissions(),
+				'attendeePermissions' => $participant->getAttendee()->getPermissions(),
 				'attendeePin' => '',
 			];
 			if ($this->talkConfig->isSIPConfigured()
@@ -997,6 +1044,8 @@ class RoomController extends AEnvironmentAwareController {
 				$result['displayName'] = $participant->getAttendee()->getDisplayName();
 			} elseif ($participant->getAttendee()->getActorType() === Attendee::ACTOR_GROUPS) {
 				$result['displayName'] = $participant->getAttendee()->getDisplayName();
+			} elseif ($participant->getAttendee()->getActorType() === Attendee::ACTOR_CIRCLES) {
+				$result['displayName'] = $participant->getAttendee()->getDisplayName();
 			}
 
 			$results[$attendeeId] = $result;
@@ -1018,15 +1067,18 @@ class RoomController extends AEnvironmentAwareController {
 	 * @return DataResponse
 	 */
 	public function addParticipantToRoom(string $newParticipant, string $source = 'users'): DataResponse {
-		if ($this->room->getType() === Room::ONE_TO_ONE_CALL || $this->room->getObjectType() === 'share:password') {
+		if ($this->room->getType() === Room::TYPE_ONE_TO_ONE || $this->room->getObjectType() === 'share:password') {
 			return new DataResponse([], Http::STATUS_BAD_REQUEST);
 		}
 
 		$participants = $this->participantService->getParticipantsForRoom($this->room);
 		$participantsByUserId = [];
+		$remoteParticipantsByFederatedId = [];
 		foreach ($participants as $participant) {
 			if ($participant->getAttendee()->getActorType() === Attendee::ACTOR_USERS) {
 				$participantsByUserId[$participant->getAttendee()->getActorId()] = $participant;
+			} elseif ($participant->getAttendee()->getAccessToken() === Attendee::ACTOR_FEDERATED_USERS) {
+				$remoteParticipantsByFederatedId[$participant->getAttendee()->getActorId()] = $participant;
 			}
 		}
 
@@ -1070,7 +1122,7 @@ class RoomController extends AEnvironmentAwareController {
 			$this->participantService->addCircle($this->room, $circle, $participants);
 		} elseif ($source === 'emails') {
 			$data = [];
-			if ($this->room->setType(Room::PUBLIC_CALL)) {
+			if ($this->room->setType(Room::TYPE_PUBLIC)) {
 				$data = ['type' => $this->room->getType()];
 			}
 
@@ -1079,7 +1131,26 @@ class RoomController extends AEnvironmentAwareController {
 			$this->guestManager->sendEmailInvitation($this->room, $participant);
 
 			return new DataResponse($data);
+		} elseif ($source === 'remotes') {
+			if (!$this->talkConfig->isFederationEnabled()) {
+				return new DataResponse([], Http::STATUS_NOT_IMPLEMENTED);
+			}
+			try {
+				$newUser = $this->cloudIdManager->resolveCloudId($newParticipant);
+			} catch (\InvalidArgumentException $e) {
+				$this->logger->error($e->getMessage(), [
+					'exception' => $e,
+				]);
+				return new DataResponse([], Http::STATUS_BAD_REQUEST);
+			}
+
+			$participantsToAdd[] = [
+				'actorType' => Attendee::ACTOR_FEDERATED_USERS,
+				'actorId' => $newUser->getId(),
+				'displayName' => $newUser->getDisplayId(),
+			];
 		} else {
+			$this->logger->error('Trying to add participant from unsupported source ' . $source);
 			return new DataResponse([], Http::STATUS_BAD_REQUEST);
 		}
 
@@ -1087,6 +1158,9 @@ class RoomController extends AEnvironmentAwareController {
 		// existing users with USER_SELF_JOINED will get converted to regular USER participants
 		foreach ($participantsToAdd as $index => $participantToAdd) {
 			$existingParticipant = $participantsByUserId[$participantToAdd['actorId']] ?? null;
+			if ($participantToAdd['actorType'] === Attendee::ACTOR_FEDERATED_USERS) {
+				$existingParticipant = $remoteParticipantsByFederatedId[$participantToAdd['actorId']] ?? null;
+			}
 
 			if ($existingParticipant !== null) {
 				unset($participantsToAdd[$index]);
@@ -1098,8 +1172,10 @@ class RoomController extends AEnvironmentAwareController {
 			}
 		}
 
+		$addedBy = $this->userManager->get($this->userId);
+
 		// add the remaining users in batch
-		$this->participantService->addUsers($this->room, $participantsToAdd);
+		$this->participantService->addUsers($this->room, $participantsToAdd, $addedBy);
 
 		return new DataResponse([]);
 	}
@@ -1115,7 +1191,7 @@ class RoomController extends AEnvironmentAwareController {
 	}
 
 	protected function removeSelfFromRoomLogic(Room $room, Participant $participant): DataResponse {
-		if ($room->getType() !== Room::ONE_TO_ONE_CALL) {
+		if ($room->getType() !== Room::TYPE_ONE_TO_ONE) {
 			if ($participant->hasModeratorPermissions(false)
 				&& $this->participantService->getNumberOfUsers($room) > 1
 				&& $this->participantService->getNumberOfModerators($room) === 1) {
@@ -1123,7 +1199,7 @@ class RoomController extends AEnvironmentAwareController {
 			}
 		}
 
-		if ($room->getType() !== Room::CHANGELOG_CONVERSATION &&
+		if ($room->getType() !== Room::TYPE_CHANGELOG &&
 			$room->getObjectType() !== 'file' &&
 			$this->participantService->getNumberOfUsers($room) === 1 &&
 			\in_array($participant->getAttendee()->getParticipantType(), [
@@ -1164,7 +1240,7 @@ class RoomController extends AEnvironmentAwareController {
 			return new DataResponse([], Http::STATUS_NOT_FOUND);
 		}
 
-		if ($this->room->getType() === Room::ONE_TO_ONE_CALL) {
+		if ($this->room->getType() === Room::TYPE_ONE_TO_ONE) {
 			return new DataResponse([], Http::STATUS_BAD_REQUEST);
 		}
 
@@ -1187,7 +1263,7 @@ class RoomController extends AEnvironmentAwareController {
 	 * @return DataResponse
 	 */
 	public function makePublic(): DataResponse {
-		if (!$this->room->setType(Room::PUBLIC_CALL)) {
+		if (!$this->room->setType(Room::TYPE_PUBLIC)) {
 			return new DataResponse([], Http::STATUS_BAD_REQUEST);
 		}
 
@@ -1201,7 +1277,7 @@ class RoomController extends AEnvironmentAwareController {
 	 * @return DataResponse
 	 */
 	public function makePrivate(): DataResponse {
-		if (!$this->room->setType(Room::GROUP_CALL)) {
+		if (!$this->room->setType(Room::TYPE_GROUP)) {
 			return new DataResponse([], Http::STATUS_BAD_REQUEST);
 		}
 
@@ -1255,7 +1331,7 @@ class RoomController extends AEnvironmentAwareController {
 	 * @return DataResponse
 	 */
 	public function setPassword(string $password): DataResponse {
-		if ($this->room->getType() !== Room::PUBLIC_CALL) {
+		if ($this->room->getType() !== Room::TYPE_PUBLIC) {
 			return new DataResponse([], Http::STATUS_FORBIDDEN);
 		}
 
@@ -1474,26 +1550,62 @@ class RoomController extends AEnvironmentAwareController {
 	 * @PublicPage
 	 * @RequireModeratorParticipant
 	 *
-	 * @param int $attendeeId
-	 * @param int $state
+	 * @param int $permissions
 	 * @return DataResponse
 	 */
-	public function setAttendeePublishingPermissions(int $attendeeId, int $state): DataResponse {
+	public function setPermissions(string $mode, int $permissions): DataResponse {
+		if (!$this->roomService->setPermissions($this->room, $mode, Attendee::PERMISSIONS_MODIFY_SET, $permissions, true)) {
+			return new DataResponse([], Http::STATUS_BAD_REQUEST);
+		}
+
+		return new DataResponse($this->formatRoom($this->room, $this->participant));
+	}
+
+	/**
+	 * @PublicPage
+	 * @RequireModeratorParticipant
+	 *
+	 * @param int $attendeeId
+	 * @param string $method
+	 * @param int $permissions
+	 * @return DataResponse
+	 */
+	public function setAttendeePermissions(int $attendeeId, string $method, int $permissions): DataResponse {
 		try {
 			$targetParticipant = $this->room->getParticipantByAttendeeId($attendeeId);
 		} catch (ParticipantNotFoundException $e) {
 			return new DataResponse([], Http::STATUS_NOT_FOUND);
 		}
 
-		if ($this->room->getType() === Room::ONE_TO_ONE_CALL) {
+		try {
+			$result = $this->participantService->updatePermissions($this->room, $targetParticipant, $method, $permissions);
+		} catch (ForbiddenException $e) {
+			return new DataResponse([], Http::STATUS_FORBIDDEN);
+		}
+
+		if (!$result) {
 			return new DataResponse([], Http::STATUS_BAD_REQUEST);
 		}
 
-		$this->participantService->updatePublishingPermissions($this->room, $targetParticipant, $state);
-
 		return new DataResponse();
 	}
 
+	/**
+	 * @PublicPage
+	 * @RequireModeratorParticipant
+	 *
+	 * @param string $method
+	 * @param int $permissions
+	 * @return DataResponse
+	 */
+	public function setAllAttendeesPermissions(string $method, int $permissions): DataResponse {
+		if (!$this->roomService->setPermissions($this->room, 'call', $method, $permissions, false)) {
+			return new DataResponse([], Http::STATUS_BAD_REQUEST);
+		}
+
+		return new DataResponse($this->formatRoom($this->room, $this->participant));
+	}
+
 	/**
 	 * @NoAdminRequired
 	 * @RequireModeratorParticipant
