@@ -216,6 +216,10 @@ class SignalingController extends OCSController {
 				],
 			]);
 
+			if (!$this->signalingManager->isCompatibleSignalingServer($response)) {
+				return new DataResponse(['error' => 'UPDATE_REQUIRED'], Http::STATUS_INTERNAL_SERVER_ERROR);
+			}
+
 			$body = $response->getBody();
 
 			$data = json_decode($body, true);
@@ -404,7 +408,7 @@ class SignalingController extends OCSController {
 				'lastPing' => $session->getLastPing(),
 				'sessionId' => $session->getSessionId(),
 				'inCall' => $session->getInCall(),
-				'publishingPermissions' => $participant->getAttendee()->getPublishingPermissions(),
+				'participantPermissions' => $participant->getPermissions(),
 			];
 		}
 
@@ -455,7 +459,7 @@ class SignalingController extends OCSController {
 	 * servers.
 	 *
 	 * See sections "Backend validation" in
-	 * https://nextcloud-talk.readthedocs.io/en/latest/standalone-signaling-api-v1.html#backend-validation
+	 * https://nextcloud-talk.readthedocs.io/en/latest/standalone-signaling-api-v1/#backend-validation
 	 *
 	 * @PublicPage
 	 *
@@ -687,10 +691,13 @@ class SignalingController extends OCSController {
 				'app' => 'spreed-hpb',
 			]);
 
-			if ($participant->getAttendee()->getPublishingPermissions() & (Attendee::PUBLISHING_PERMISSIONS_AUDIO | Attendee::PUBLISHING_PERMISSIONS_VIDEO)) {
-				$permissions[] = 'publish-media';
+			if ($participant->getPermissions() & Attendee::PERMISSIONS_PUBLISH_AUDIO) {
+				$permissions[] = 'publish-audio';
 			}
-			if ($participant->getAttendee()->getPublishingPermissions() & Attendee::PUBLISHING_PERMISSIONS_SCREENSHARING) {
+			if ($participant->getPermissions() & Attendee::PERMISSIONS_PUBLISH_VIDEO) {
+				$permissions[] = 'publish-video';
+			}
+			if ($participant->getPermissions() & Attendee::PERMISSIONS_PUBLISH_SCREEN) {
 				$permissions[] = 'publish-screen';
 			}
 			if ($participant->hasModeratorPermissions(false)) {
