@@ -23,6 +23,7 @@ declare(strict_types=1);
 
 namespace OCA\Talk\Notification;
 
+use OCA\FederatedFileSharing\AddressHandler;
 use OCA\Talk\Chat\CommentsManager;
 use OCA\Talk\Chat\MessageParser;
 use OCA\Talk\Config;
@@ -36,6 +37,7 @@ use OCA\Talk\Room;
 use OCA\Talk\Service\ParticipantService;
 use OCP\Comments\ICommentsManager;
 use OCP\Comments\NotFoundException;
+use OCP\HintException;
 use OCP\IL10N;
 use OCP\IURLGenerator;
 use OCP\IUser;
@@ -77,6 +79,8 @@ class Notifier implements INotifier {
 	protected $messageParser;
 	/** @var Definitions */
 	protected $definitions;
+	/** @var AddressHandler */
+	protected $addressHandler;
 
 	/** @var Room[] */
 	protected $rooms = [];
@@ -94,7 +98,8 @@ class Notifier implements INotifier {
 								INotificationManager $notificationManager,
 								CommentsManager $commentManager,
 								MessageParser $messageParser,
-								Definitions $definitions) {
+								Definitions $definitions,
+								AddressHandler $addressHandler) {
 		$this->lFactory = $lFactory;
 		$this->url = $url;
 		$this->config = $config;
@@ -107,6 +112,7 @@ class Notifier implements INotifier {
 		$this->commentManager = $commentManager;
 		$this->messageParser = $messageParser;
 		$this->definitions = $definitions;
+		$this->addressHandler = $addressHandler;
 	}
 
 	/**
@@ -258,6 +264,10 @@ class Notifier implements INotifier {
 			return $this->parseChatMessage($notification, $room, $participant, $l);
 		}
 
+		if ($subject === 'remote_talk_share') {
+			return $this->parseRemoteInvitationMessage($notification, $l);
+		}
+
 		$this->notificationManager->markProcessed($notification);
 		throw new \InvalidArgumentException('Unknown subject');
 	}
@@ -270,6 +280,47 @@ class Notifier implements INotifier {
 		return $temp;
 	}
 
+	/**
+	 * @throws HintException
+	 */
+	protected function parseRemoteInvitationMessage(INotification $notification, IL10N $l): INotification {
+		$subjectParameters = $notification->getSubjectParameters();
+
+		[$sharedById, $sharedByServer] = $this->addressHandler->splitUserRemote($subjectParameters['sharedByFederatedId']);
+
+		$message = $l->t('{user1} shared room {roomName} on {remoteServer} with you');
+
+		$rosParameters = [
+			'user1' => [
+				'type' => 'user',
+				'id' => $sharedById,
+				'name' => $subjectParameters['sharedByDisplayName'],
+				'server' => $sharedByServer,
+			],
+			'roomName' => [
+				'type' => 'highlight',
+				'id' => $subjectParameters['serverUrl'] . '::' . $subjectParameters['roomToken'],
+				'name' => $subjectParameters['roomName'],
+			],
+			'remoteServer' => [
+				'type' => 'highlight',
+				'id' => $subjectParameters['serverUrl'],
+				'name' => $subjectParameters['serverUrl'],
+			]
+		];
+
+		$placeholders = $replacements = [];
+		foreach ($rosParameters as $placeholder => $parameter) {
+			$placeholders[] = '{' . $placeholder .'}';
+			$replacements[] = $parameter['name'];
+		}
+
+		$notification->setParsedMessage(str_replace($placeholders, $replacements, $message));
+		$notification->setRichMessage($message, $rosParameters);
+
+		return $notification;
+	}
+
 	/**
 	 * @param INotification $notification
 	 * @param Room $room
@@ -358,7 +409,7 @@ class Notifier implements INotifier {
 				'id' => $message->getComment()->getId(),
 				'name' => $shortenMessage,
 			];
-			if ($room->getType() === Room::ONE_TO_ONE_CALL) {
+			if ($room->getType() === Room::TYPE_ONE_TO_ONE) {
 				$subject = "{user}\n{message}";
 			} elseif ($richSubjectUser) {
 				$subject = $l->t('{user} in {call}') . "\n{message}";
@@ -373,7 +424,7 @@ class Notifier implements INotifier {
 				}
 			}
 		} elseif ($notification->getSubject() === 'chat') {
-			if ($room->getType() === Room::ONE_TO_ONE_CALL) {
+			if ($room->getType() === Room::TYPE_ONE_TO_ONE) {
 				$subject = $l->t('{user} sent you a private message');
 			} elseif ($richSubjectUser) {
 				$subject = $l->t('{user} sent a message in conversation {call}');
@@ -388,7 +439,7 @@ class Notifier implements INotifier {
 				}
 			}
 		} elseif ($notification->getSubject() === 'reply') {
-			if ($room->getType() === Room::ONE_TO_ONE_CALL) {
+			if ($room->getType() === Room::TYPE_ONE_TO_ONE) {
 				$subject = $l->t('{user} replied to your private message');
 			} elseif ($richSubjectUser) {
 				$subject = $l->t('{user} replied to your message in conversation {call}');
@@ -402,7 +453,7 @@ class Notifier implements INotifier {
 					$subject = $l->t('A guest replied to your message in conversation {call}');
 				}
 			}
-		} elseif ($room->getType() === Room::ONE_TO_ONE_CALL) {
+		} elseif ($room->getType() === Room::TYPE_ONE_TO_ONE) {
 			$subject = $l->t('{user} mentioned you in a private conversation');
 		} elseif ($richSubjectUser) {
 			$subject = $l->t('{user} mentioned you in conversation {call}');
@@ -461,11 +512,11 @@ class Notifier implements INotifier {
 	 */
 	protected function getRoomType(Room $room): string {
 		switch ($room->getType()) {
-			case Room::ONE_TO_ONE_CALL:
+			case Room::TYPE_ONE_TO_ONE:
 				return 'one2one';
-			case Room::GROUP_CALL:
+			case Room::TYPE_GROUP:
 				return 'group';
-			case Room::PUBLIC_CALL:
+			case Room::TYPE_PUBLIC:
 				return 'public';
 			default:
 				throw new \InvalidArgumentException('Unknown room type');
@@ -494,7 +545,7 @@ class Notifier implements INotifier {
 		}
 
 		$roomName = $room->getDisplayName($notification->getUser());
-		if ($room->getType() === Room::ONE_TO_ONE_CALL) {
+		if ($room->getType() === Room::TYPE_ONE_TO_ONE) {
 			$subject = $l->t('{user} invited you to a private conversation');
 			if ($this->participantService->hasActiveSessionsInCall($room)) {
 				$notification = $this->addActionButton($notification, $l->t('Join call'));
@@ -519,7 +570,7 @@ class Notifier implements INotifier {
 						],
 					]
 				);
-		} elseif (\in_array($room->getType(), [Room::GROUP_CALL, Room::PUBLIC_CALL], true)) {
+		} elseif (\in_array($room->getType(), [Room::TYPE_GROUP, Room::TYPE_PUBLIC], true)) {
 			$subject = $l->t('{user} invited you to a group conversation: {call}');
 			if ($this->participantService->hasActiveSessionsInCall($room)) {
 				$notification = $this->addActionButton($notification, $l->t('Join call'));
@@ -565,7 +616,7 @@ class Notifier implements INotifier {
 		}
 
 		$roomName = $room->getDisplayName($notification->getUser());
-		if ($room->getType() === Room::ONE_TO_ONE_CALL) {
+		if ($room->getType() === Room::TYPE_ONE_TO_ONE) {
 			$parameters = $notification->getSubjectParameters();
 			$calleeId = $parameters['callee'];
 			$user = $this->userManager->get($calleeId);
@@ -598,7 +649,7 @@ class Notifier implements INotifier {
 			} else {
 				throw new AlreadyProcessedException();
 			}
-		} elseif (\in_array($room->getType(), [Room::GROUP_CALL, Room::PUBLIC_CALL], true)) {
+		} elseif (\in_array($room->getType(), [Room::TYPE_GROUP, Room::TYPE_PUBLIC], true)) {
 			if ($this->notificationManager->isPreparingPushNotification() || $this->participantService->hasActiveSessionsInCall($room)) {
 				$notification = $this->addActionButton($notification, $l->t('Join call'));
 				$subject = $l->t('A group call has started in {call}');
