@@ -23,7 +23,7 @@ declare(strict_types=1);
 
 namespace OCA\Talk\Service;
 
-use OCA\Circles\Api\v1\Circles;
+use OCA\Circles\CirclesManager;
 use OCA\Circles\Model\Circle;
 use OCA\Circles\Model\Member;
 use OCA\Talk\Config;
@@ -32,14 +32,19 @@ use OCA\Talk\Events\AttendeesAddedEvent;
 use OCA\Talk\Events\AttendeesRemovedEvent;
 use OCA\Talk\Events\JoinRoomGuestEvent;
 use OCA\Talk\Events\JoinRoomUserEvent;
+use OCA\Talk\Events\ModifyEveryoneEvent;
 use OCA\Talk\Events\ModifyParticipantEvent;
+use OCA\Talk\Events\ModifyRoomEvent;
 use OCA\Talk\Events\ParticipantEvent;
 use OCA\Talk\Events\RemoveParticipantEvent;
 use OCA\Talk\Events\RemoveUserEvent;
 use OCA\Talk\Events\RoomEvent;
+use OCA\Talk\Exceptions\ForbiddenException;
 use OCA\Talk\Exceptions\InvalidPasswordException;
 use OCA\Talk\Exceptions\ParticipantNotFoundException;
 use OCA\Talk\Exceptions\UnauthorizedException;
+use OCA\Talk\Federation\FederationManager;
+use OCA\Talk\Federation\Notifications;
 use OCA\Talk\Model\Attendee;
 use OCA\Talk\Model\AttendeeMapper;
 use OCA\Talk\Model\SelectHelper;
@@ -51,14 +56,15 @@ use OCA\Talk\Webinary;
 use OCP\AppFramework\Db\DoesNotExistException;
 use OCP\AppFramework\Utility\ITimeFactory;
 use OCP\Comments\IComment;
+use OCP\DB\Exception;
 use OCP\DB\QueryBuilder\IQueryBuilder;
 use OCP\EventDispatcher\IEventDispatcher;
 use OCP\IConfig;
 use OCP\IDBConnection;
 use OCP\IGroup;
+use OCP\IGroupManager;
 use OCP\IUser;
 use OCP\IUserManager;
-use OCP\IGroupManager;
 use OCP\Security\ISecureRandom;
 
 class ParticipantService {
@@ -82,6 +88,10 @@ class ParticipantService {
 	private $userManager;
 	/** @var IGroupManager */
 	private $groupManager;
+	/** @var MembershipService */
+	private $membershipService;
+	/** @var Notifications */
+	private $notifications;
 	/** @var ITimeFactory */
 	private $timeFactory;
 
@@ -95,6 +105,8 @@ class ParticipantService {
 								IEventDispatcher $dispatcher,
 								IUserManager $userManager,
 								IGroupManager $groupManager,
+								MembershipService $membershipService,
+								Notifications $notifications,
 								ITimeFactory $timeFactory) {
 		$this->serverConfig = $serverConfig;
 		$this->talkConfig = $talkConfig;
@@ -106,7 +118,9 @@ class ParticipantService {
 		$this->dispatcher = $dispatcher;
 		$this->userManager = $userManager;
 		$this->groupManager = $groupManager;
+		$this->membershipService = $membershipService;
 		$this->timeFactory = $timeFactory;
+		$this->notifications = $notifications;
 	}
 
 	public function updateParticipantType(Room $room, Participant $participant, int $participantType): void {
@@ -128,23 +142,53 @@ class ParticipantService {
 		$this->dispatcher->dispatch(Room::EVENT_AFTER_PARTICIPANT_TYPE_SET, $event);
 	}
 
-	public function updatePublishingPermissions(Room $room, Participant $participant, int $newState): void {
+	/**
+	 * @throws Exception
+	 * @throws ForbiddenException
+	 */
+	public function updatePermissions(Room $room, Participant $participant, string $method, int $newPermissions): bool {
+		if ($room->getType() === Room::TYPE_ONE_TO_ONE) {
+			return false;
+		}
+
+		if ($participant->hasModeratorPermissions()) {
+			throw new ForbiddenException();
+		}
+
 		$attendee = $participant->getAttendee();
 
 		if ($attendee->getActorType() === Attendee::ACTOR_GROUPS || $attendee->getActorType() === Attendee::ACTOR_CIRCLES) {
 			// Can not set publishing permissions for those actor types
-			return;
+			return false;
 		}
 
-		$oldState = $attendee->getPublishingPermissions();
+		$oldPermissions = $participant->getPermissions();
+		if ($method === Attendee::PERMISSIONS_MODIFY_SET) {
+			if ($newPermissions !== Attendee::PERMISSIONS_DEFAULT) {
+				// Make sure the custom flag is set when not setting to default permissions
+				$newPermissions |= Attendee::PERMISSIONS_CUSTOM;
+			}
+		} elseif ($method === Attendee::PERMISSIONS_MODIFY_ADD) {
+			$newPermissions = $oldPermissions | $newPermissions;
+		} elseif ($method === Attendee::PERMISSIONS_MODIFY_REMOVE) {
+			$newPermissions = $oldPermissions & ~$newPermissions;
+		} else {
+			return false;
+		}
 
-		$event = new ModifyParticipantEvent($room, $participant, 'publishingPermissions', $newState, $oldState);
-		$this->dispatcher->dispatch(Room::EVENT_BEFORE_PARTICIPANT_PUBLISHING_PERMISSIONS_SET, $event);
+		$event = new ModifyParticipantEvent($room, $participant, 'permissions', $newPermissions, $oldPermissions);
+		$this->dispatcher->dispatch(Room::EVENT_BEFORE_PARTICIPANT_PERMISSIONS_SET, $event);
 
-		$attendee->setPublishingPermissions($newState);
+		$attendee->setPermissions($newPermissions);
 		$this->attendeeMapper->update($attendee);
 
-		$this->dispatcher->dispatch(Room::EVENT_AFTER_PARTICIPANT_PUBLISHING_PERMISSIONS_SET, $event);
+		$this->dispatcher->dispatch(Room::EVENT_AFTER_PARTICIPANT_PERMISSIONS_SET, $event);
+
+		return true;
+	}
+
+	public function updateAllPermissions(Room $room, string $method, int $newState): void {
+		$this->attendeeMapper->modifyPermissions($room->getId(), $method, $newState);
 	}
 
 	public function updateLastReadMessage(Participant $participant, int $lastReadMessage): void {
@@ -178,6 +222,23 @@ class ParticipantService {
 		$this->attendeeMapper->update($attendee);
 	}
 
+	/**
+	 * @param Participant $participant
+	 * @param int $level
+	 */
+	public function updateNotificationCalls(Participant $participant, int $level): void {
+		if (!\in_array($level, [
+			Participant::NOTIFY_CALLS_OFF,
+			Participant::NOTIFY_CALLS_ON,
+		], true)) {
+			throw new \InvalidArgumentException('Invalid notification level');
+		}
+
+		$attendee = $participant->getAttendee();
+		$attendee->setNotificationCalls($level);
+		$this->attendeeMapper->update($attendee);
+	}
+
 	/**
 	 * @param Room $room
 	 * @param IUser $user
@@ -207,7 +268,7 @@ class ParticipantService {
 			$manager = \OC::$server->get(\OCA\Talk\Manager::class);
 
 			// User joining a group or public call through listing
-			if (($room->getType() === Room::GROUP_CALL || $room->getType() === Room::PUBLIC_CALL) &&
+			if (($room->getType() === Room::TYPE_GROUP || $room->getType() === Room::TYPE_PUBLIC) &&
 				$manager->isRoomListableByUser($room, $user->getUID())
 			) {
 				$this->addUsers($room, [[
@@ -216,15 +277,15 @@ class ParticipantService {
 					'displayName' => $user->getDisplayName(),
 					// need to use "USER" here, because "USER_SELF_JOINED" only works for public calls
 					'participantType' => Participant::USER,
-				]]);
-			} elseif ($room->getType() === Room::PUBLIC_CALL) {
+				]], $user);
+			} elseif ($room->getType() === Room::TYPE_PUBLIC) {
 				// User joining a public room, without being invited
 				$this->addUsers($room, [[
 					'actorType' => Attendee::ACTOR_USERS,
 					'actorId' => $user->getUID(),
 					'displayName' => $user->getDisplayName(),
 					'participantType' => Participant::USER_SELF_JOINED,
-				]]);
+				]], $user);
 			} else {
 				// shouldn't happen unless some code called joinRoom without previous checks
 				throw new UnauthorizedException('Participant is not allowed to join');
@@ -276,6 +337,7 @@ class ParticipantService {
 			$attendee->setActorType(Attendee::ACTOR_GUESTS);
 			$attendee->setActorId($randomActorId);
 			$attendee->setParticipantType(Participant::GUEST);
+			$attendee->setPermissions(Attendee::PERMISSIONS_DEFAULT);
 			$attendee->setLastReadMessage($lastMessage);
 			$this->attendeeMapper->insert($attendee);
 
@@ -299,8 +361,10 @@ class ParticipantService {
 	/**
 	 * @param Room $room
 	 * @param array $participants
+	 * @param IUser|null $addedBy User that is attempting to add these users (must be set for federated users to be added)
+	 * @throws \Exception thrown if $addedBy is not set when adding a federated user
 	 */
-	public function addUsers(Room $room, array $participants): void {
+	public function addUsers(Room $room, array $participants, ?IUser $addedBy = null): void {
 		if (empty($participants)) {
 			return;
 		}
@@ -317,6 +381,14 @@ class ParticipantService {
 			$readPrivacy = Participant::PRIVACY_PUBLIC;
 			if ($participant['actorType'] === Attendee::ACTOR_USERS) {
 				$readPrivacy = $this->talkConfig->getUserReadPrivacy($participant['actorId']);
+			} elseif ($participant['actorType'] === Attendee::ACTOR_FEDERATED_USERS) {
+				if ($addedBy === null) {
+					throw new \Exception('$addedBy must be set to add a federated user');
+				}
+				$participant['accessToken'] = $this->secureRandom->generate(
+					FederationManager::TOKEN_LENGTH,
+					ISecureRandom::CHAR_HUMAN_READABLE
+				);
 			}
 
 			$attendee = new Attendee();
@@ -326,18 +398,60 @@ class ParticipantService {
 			if (isset($participant['displayName'])) {
 				$attendee->setDisplayName($participant['displayName']);
 			}
+			if (isset($participant['accessToken'])) {
+				$attendee->setAccessToken($participant['accessToken']);
+			}
+			if (isset($participant['remoteId'])) {
+				$attendee->setRemoteId($participant['remoteId']);
+			}
 			$attendee->setParticipantType($participant['participantType'] ?? Participant::USER);
+			$attendee->setPermissions(Attendee::PERMISSIONS_DEFAULT);
 			$attendee->setLastReadMessage($lastMessage);
 			$attendee->setReadPrivacy($readPrivacy);
-			$this->attendeeMapper->insert($attendee);
+			try {
+				$entity = $this->attendeeMapper->insert($attendee);
+				$attendees[] = $attendee;
 
-			$attendees[] = $attendee;
+				if ($attendee->getActorType() === Attendee::ACTOR_FEDERATED_USERS) {
+					$this->notifications->sendRemoteShare((string) $entity->getId(), $participant['accessToken'], $participant['actorId'], $addedBy->getDisplayName(), $addedBy->getCloudId(), 'user', $room, $this->getHighestPermissionAttendee($room));
+				}
+			} catch (Exception $e) {
+				if ($e->getReason() !== Exception::REASON_UNIQUE_CONSTRAINT_VIOLATION) {
+					throw $e;
+				}
+			}
 		}
 
-		$attendeeEvent = new AttendeesAddedEvent($room, $attendees);
-		$this->dispatcher->dispatchTyped($attendeeEvent);
+		if (!empty($attendees)) {
+			$attendeeEvent = new AttendeesAddedEvent($room, $attendees);
+			$this->dispatcher->dispatchTyped($attendeeEvent);
 
-		$this->dispatcher->dispatch(Room::EVENT_AFTER_USERS_ADD, $event);
+			$this->dispatcher->dispatch(Room::EVENT_AFTER_USERS_ADD, $event);
+		}
+	}
+
+	public function getHighestPermissionAttendee(Room $room): ?Attendee {
+		try {
+			$roomOwners = $this->attendeeMapper->getActorsByParticipantTypes($room->getId(), [Participant::OWNER]);
+
+			if (!empty($roomOwners)) {
+				foreach ($roomOwners as $owner) {
+					if ($owner->getActorType() === Attendee::ACTOR_USERS) {
+						return $owner;
+					}
+				}
+			}
+			$roomModerators = $this->attendeeMapper->getActorsByParticipantTypes($room->getId(), [Participant::MODERATOR]);
+			if (!empty($roomOwners)) {
+				foreach ($roomModerators as $moderator) {
+					if ($moderator->getActorType() === Attendee::ACTOR_USERS) {
+						return $moderator;
+					}
+				}
+			}
+		} catch (Exception $e) {
+		}
+		return null;
 	}
 
 	/**
@@ -387,6 +501,7 @@ class ParticipantService {
 			$attendee->setActorId($group->getGID());
 			$attendee->setDisplayName($group->getDisplayName());
 			$attendee->setParticipantType(Participant::USER);
+			$attendee->setPermissions(Attendee::PERMISSIONS_DEFAULT);
 			$attendee->setReadPrivacy(Participant::PRIVACY_PRIVATE);
 			$this->attendeeMapper->insert($attendee);
 
@@ -405,20 +520,23 @@ class ParticipantService {
 	 */
 	public function getCircle(string $circleId, string $userId): Circle {
 		try {
-			$circle = Circles::detailsCircle($circleId);
+			$circlesManager = \OC::$server->get(CirclesManager::class);
+			$federatedUser = $circlesManager->getFederatedUser($userId, Member::TYPE_USER);
+			$federatedUser->getLink($circleId);
 		} catch (\Exception $e) {
-			throw new ParticipantNotFoundException('Circle not found');
+			throw new ParticipantNotFoundException('Circle not found or not a member');
 		}
 
-		// FIXME use \OCA\Circles\Manager::getLink() in the future
-		$membersInCircle = $circle->getInheritedMembers();
-		foreach ($membersInCircle as $member) {
-			if ($member->isLocal() && $member->getUserType() === Member::TYPE_USER && $member->getUserId() === $userId) {
-				return $circle;
-			}
+		$circlesManager->startSession($federatedUser);
+		try {
+			$circle = $circlesManager->getCircle($circleId);
+			$circlesManager->stopSession();
+			return $circle;
+		} catch (\Exception $e) {
 		}
 
-		throw new ParticipantNotFoundException('Circle found but not a member');
+		$circlesManager->stopSession();
+		throw new ParticipantNotFoundException('Circle not found or not a member');
 	}
 
 	/**
@@ -427,7 +545,7 @@ class ParticipantService {
 	 * @param Participant[] $existingParticipants
 	 */
 	public function addCircle(Room $room, Circle $circle, array $existingParticipants = []): void {
-		$membersInCircle = $circle->getMembers();
+		$membersInCircle = $circle->getInheritedMembers();
 
 		if (empty($existingParticipants)) {
 			$existingParticipants = $this->getParticipantsForRoom($room);
@@ -475,22 +593,22 @@ class ParticipantService {
 			];
 		}
 
-		// No tracking of circles for now
-//		try {
-//			$this->attendeeMapper->findByActor($room->getId(), Attendee::ACTOR_CIRCLES, $circle->getSingleId());
-//		} catch (DoesNotExistException $e) {
-//			$attendee = new Attendee();
-//			$attendee->setRoomId($room->getId());
-//			$attendee->setActorType(Attendee::ACTOR_CIRCLES);
-//			$attendee->setActorId($circle->getSingleId());
-//			$attendee->setDisplayName($circle->getDisplayName());
-//			$attendee->setParticipantType(Participant::USER);
-//			$attendee->setReadPrivacy(Participant::PRIVACY_PRIVATE);
-//			$this->attendeeMapper->insert($attendee);
-//
-//			$attendeeEvent = new AttendeesAddedEvent($room, [$attendee]);
-//			$this->dispatcher->dispatchTyped($attendeeEvent);
-//		}
+		try {
+			$this->attendeeMapper->findByActor($room->getId(), Attendee::ACTOR_CIRCLES, $circle->getSingleId());
+		} catch (DoesNotExistException $e) {
+			$attendee = new Attendee();
+			$attendee->setRoomId($room->getId());
+			$attendee->setActorType(Attendee::ACTOR_CIRCLES);
+			$attendee->setActorId($circle->getSingleId());
+			$attendee->setDisplayName($circle->getDisplayName());
+			$attendee->setParticipantType(Participant::USER);
+			$attendee->setPermissions(Attendee::PERMISSIONS_DEFAULT);
+			$attendee->setReadPrivacy(Participant::PRIVACY_PRIVATE);
+			$this->attendeeMapper->insert($attendee);
+
+			$attendeeEvent = new AttendeesAddedEvent($room, [$attendee]);
+			$this->dispatcher->dispatchTyped($attendeeEvent);
+		}
 
 		$this->addUsers($room, $newParticipants);
 	}
@@ -539,7 +657,7 @@ class ParticipantService {
 	}
 
 	public function ensureOneToOneRoomIsFilled(Room $room): void {
-		if ($room->getType() !== Room::ONE_TO_ONE_CALL) {
+		if ($room->getType() !== Room::TYPE_ONE_TO_ONE) {
 			return;
 		}
 
@@ -621,40 +739,96 @@ class ParticipantService {
 
 		if ($participant->getAttendee()->getActorType() === Attendee::ACTOR_GROUPS) {
 			$this->removeGroupMembers($room, $participant, $reason);
+		} elseif ($participant->getAttendee()->getActorType() === Attendee::ACTOR_CIRCLES) {
+			$this->removeCircleMembers($room, $participant, $reason);
 		}
 	}
 
+	public function getActorsByType(Room $room, string $actorType): array {
+		return $this->attendeeMapper->getActorsByType($room->getId(), $actorType);
+	}
+
 	public function removeGroupMembers(Room $room, Participant $removedGroupParticipant, string $reason): void {
 		$removedGroup = $this->groupManager->get($removedGroupParticipant->getAttendee()->getActorId());
 		if (!$removedGroup instanceof IGroup) {
 			return;
 		}
 
-		$attendeeGroups = $this->attendeeMapper->getActorsByType($room->getId(), Attendee::ACTOR_GROUPS);
-
-		$groupsInRoom = [];
-		foreach ($attendeeGroups as $attendee) {
-			$groupsInRoom[] = $attendee->getActorId();
-		}
-
+		$users = $this->membershipService->getUsersWithoutOtherMemberships($room, $removedGroup->getUsers());
 		$attendees = [];
-		foreach ($removedGroup->getUsers() as $user) {
+		foreach ($users as $user) {
 			try {
 				$participant = $room->getParticipant($user->getUID());
+				$participantType = $participant->getAttendee()->getParticipantType();
+
+				$attendees[] = $participant->getAttendee();
+				if ($participantType === Participant::USER) {
+					// Only remove normal users, not moderators/admins
+					$this->removeAttendee($room, $participant, $reason, true);
+				}
 			} catch (ParticipantNotFoundException $e) {
+			}
+		}
+
+		$attendeeEvent = new AttendeesRemovedEvent($room, $attendees);
+		$this->dispatcher->dispatchTyped($attendeeEvent);
+	}
+
+	public function removeCircleMembers(Room $room, Participant $removedCircleParticipant, string $reason): void {
+		try {
+			$circlesManager = \OC::$server->get(CirclesManager::class);
+			$circlesManager->startSuperSession();
+			$circle = $circlesManager->getCircle($removedCircleParticipant->getAttendee()->getActorId());
+			$circlesManager->stopSession();
+		} catch (\Exception $e) {
+			// Circles not enabled
+			return;
+		}
+
+		$circlesManager->startSuperSession();
+		try {
+			$circle = $circlesManager->getCircle($removedCircleParticipant->getAttendee()->getActorId());
+			$circlesManager->stopSession();
+		} catch (\Exception $e) {
+			$circlesManager->stopSession();
+			return;
+		}
+
+		$membersInCircle = $circle->getInheritedMembers();
+		$users = [];
+		foreach ($membersInCircle as $member) {
+			/** @var Member $member */
+			if ($member->getUserType() !== Member::TYPE_USER || $member->getUserId() === '') {
+				// Not a user?
 				continue;
 			}
 
-			$userGroups = $this->groupManager->getUserGroupIds($user);
-			$stillHasGroup = array_intersect($userGroups, $groupsInRoom);
-			if (!empty($stillHasGroup)) {
+			if ($member->getStatus() !== Member::STATUS_INVITED && $member->getStatus() !== Member::STATUS_MEMBER) {
+				// Only allow invited and regular members
 				continue;
 			}
 
-			$attendees[] = $participant->getAttendee();
-			if ($participant->getAttendee()->getParticipantType() === Participant::USER) {
-				// Only remove normal users, not moderators/admins
-				$this->removeAttendee($room, $participant, $reason, true);
+			$users[] = $this->userManager->get($member->getUserId());
+		}
+
+
+		if (empty($users)) {
+			return;
+		}
+
+		$users = $this->membershipService->getUsersWithoutOtherMemberships($room, $users);
+		$attendees = [];
+		foreach ($users as $user) {
+			try {
+				$participant = $room->getParticipant($user->getUID());
+				$participantType = $participant->getAttendee()->getParticipantType();
+
+				$attendees[] = $participant->getAttendee();
+				if ($participantType === Participant::USER) {
+					// Only remove normal users, not moderators/admins
+					$this->removeAttendee($room, $participant, $reason, true);
+				}
+			} catch (ParticipantNotFoundException $e) {
 			}
 		}
 
@@ -697,10 +871,10 @@ class ParticipantService {
 			->leftJoin('s', 'talk_attendees', 'a', $query->expr()->eq('s.attendee_id', 'a.id'))
 			->where($query->expr()->eq('a.room_id', $query->createNamedParameter($room->getId(), IQueryBuilder::PARAM_INT)))
 			->andWhere($query->expr()->eq('a.actor_type', $query->createNamedParameter(Attendee::ACTOR_GUESTS)))
-			->andWhere($query->expr()->lte('s.last_ping', $query->createNamedParameter($this->timeFactory->getTime() - 100, IQueryBuilder::PARAM_INT)));
+			->andWhere($query->expr()->lte('s.last_ping', $query->createNamedParameter($this->timeFactory->getTime() - Session::SESSION_TIMEOUT_KILL, IQueryBuilder::PARAM_INT)));
 
 		$sessionTableIds = [];
-		$result = $query->execute();
+		$result = $query->executeQuery();
 		while ($row = $result->fetch()) {
 			$sessionTableIds[] = (int) $row['s_id'];
 		}
@@ -719,7 +893,7 @@ class ParticipantService {
 
 		$attendeeIds = [];
 		$attendees = [];
-		$result = $query->execute();
+		$result = $query->executeQuery();
 		while ($row = $result->fetch()) {
 			$attendeeIds[] = (int) $row['a_id'];
 			$attendees[] = $this->attendeeMapper->createAttendeeFromRow($row);
@@ -734,24 +908,43 @@ class ParticipantService {
 		$this->dispatcher->dispatch(Room::EVENT_AFTER_GUESTS_CLEAN, $event);
 	}
 
-	public function changeInCall(Room $room, Participant $participant, int $flags): void {
+	public function endCallForEveryone(Room $room, Participant $moderator): void {
+		$event = new ModifyRoomEvent($room, 'in_call', Participant::FLAG_DISCONNECTED, null, $moderator);
+		$this->dispatcher->dispatch(Room::EVENT_BEFORE_END_CALL_FOR_EVERYONE, $event);
+
+		$participants = $this->getParticipantsInCall($room);
+
+		// kick out all participants out of the call
+		foreach ($participants as $participant) {
+			$this->changeInCall($room, $participant, Participant::FLAG_DISCONNECTED, true);
+		}
+
+		$this->dispatcher->dispatch(Room::EVENT_AFTER_END_CALL_FOR_EVERYONE, $event);
+	}
+
+	public function changeInCall(Room $room, Participant $participant, int $flags, bool $endCallForEveryone = false): void {
 		$session = $participant->getSession();
 		if (!$session instanceof Session) {
 			return;
 		}
 
-		$publishingPermissions = $participant->getAttendee()->getPublishingPermissions();
-		if (!($publishingPermissions & Attendee::PUBLISHING_PERMISSIONS_AUDIO)) {
+		$permissions = $participant->getPermissions();
+		if (!($permissions & Attendee::PERMISSIONS_PUBLISH_AUDIO)) {
 			$flags &= ~Participant::FLAG_WITH_AUDIO;
 		}
-		if (!($publishingPermissions & Attendee::PUBLISHING_PERMISSIONS_VIDEO)) {
+		if (!($permissions & Attendee::PERMISSIONS_PUBLISH_VIDEO)) {
 			$flags &= ~Participant::FLAG_WITH_VIDEO;
 		}
 
-		$event = new ModifyParticipantEvent($room, $participant, 'inCall', $flags, $session->getInCall());
 		if ($flags !== Participant::FLAG_DISCONNECTED) {
+			$event = new ModifyParticipantEvent($room, $participant, 'inCall', $flags, $session->getInCall());
 			$this->dispatcher->dispatch(Room::EVENT_BEFORE_SESSION_JOIN_CALL, $event);
 		} else {
+			if ($endCallForEveryone) {
+				$event = new ModifyEveryoneEvent($room, $participant, 'inCall', $flags, $session->getInCall());
+			} else {
+				$event = new ModifyParticipantEvent($room, $participant, 'inCall', $flags, $session->getInCall());
+			}
 			$this->dispatcher->dispatch(Room::EVENT_BEFORE_SESSION_LEAVE_CALL, $event);
 		}
 
@@ -785,11 +978,11 @@ class ParticipantService {
 			throw new \InvalidArgumentException('Invalid flags');
 		}
 
-		$publishingPermissions = $participant->getAttendee()->getPublishingPermissions();
-		if (!($publishingPermissions & Attendee::PUBLISHING_PERMISSIONS_AUDIO)) {
+		$permissions = $participant->getPermissions();
+		if (!($permissions & Attendee::PERMISSIONS_PUBLISH_AUDIO)) {
 			$flags &= ~Participant::FLAG_WITH_AUDIO;
 		}
-		if (!($publishingPermissions & Attendee::PUBLISHING_PERMISSIONS_VIDEO)) {
+		if (!($permissions & Attendee::PERMISSIONS_PUBLISH_VIDEO)) {
 			$flags &= ~Participant::FLAG_WITH_VIDEO;
 		}
 
@@ -802,41 +995,52 @@ class ParticipantService {
 		$this->dispatcher->dispatch(Room::EVENT_AFTER_SESSION_UPDATE_CALL_FLAGS, $event);
 	}
 
-	public function markUsersAsMentioned(Room $room, array $userIds, int $messageId): void {
-		$query = $this->connection->getQueryBuilder();
-		$query->update('talk_attendees')
-			->set('last_mention_message', $query->createNamedParameter($messageId, IQueryBuilder::PARAM_INT))
-			->where($query->expr()->eq('room_id', $query->createNamedParameter($room->getId(), IQueryBuilder::PARAM_INT)))
-			->andWhere($query->expr()->eq('actor_type', $query->createNamedParameter(Attendee::ACTOR_USERS)))
-			->andWhere($query->expr()->in('actor_id', $query->createNamedParameter($userIds, IQueryBuilder::PARAM_STR_ARRAY)));
-		$query->execute();
+	public function markUsersAsMentioned(Room $room, array $userIds, int $messageId, array $usersDirectlyMentioned): void {
+		$update = $this->connection->getQueryBuilder();
+		$update->update('talk_attendees')
+			->set('last_mention_message', $update->createNamedParameter($messageId, IQueryBuilder::PARAM_INT))
+			->where($update->expr()->eq('room_id', $update->createNamedParameter($room->getId(), IQueryBuilder::PARAM_INT)))
+			->andWhere($update->expr()->eq('actor_type', $update->createNamedParameter(Attendee::ACTOR_USERS)))
+			->andWhere($update->expr()->in('actor_id', $update->createNamedParameter($userIds, IQueryBuilder::PARAM_STR_ARRAY)));
+		$update->executeStatement();
+
+		if (!empty($usersDirectlyMentioned)) {
+			$update = $this->connection->getQueryBuilder();
+			$update->update('talk_attendees')
+				->set('last_mention_direct', $update->createNamedParameter($messageId, IQueryBuilder::PARAM_INT))
+				->where($update->expr()->eq('room_id', $update->createNamedParameter($room->getId(), IQueryBuilder::PARAM_INT)))
+				->andWhere($update->expr()->eq('actor_type', $update->createNamedParameter(Attendee::ACTOR_USERS)))
+				->andWhere($update->expr()->in('actor_id', $update->createNamedParameter($usersDirectlyMentioned, IQueryBuilder::PARAM_STR_ARRAY)));
+			$update->executeStatement();
+		}
 	}
 
 	public function resetChatDetails(Room $room): void {
-		$query = $this->connection->getQueryBuilder();
-		$query->update('talk_attendees')
-			->set('last_read_message', $query->createNamedParameter(0, IQueryBuilder::PARAM_INT))
-			->set('last_mention_message', $query->createNamedParameter(0, IQueryBuilder::PARAM_INT))
-			->where($query->expr()->eq('room_id', $query->createNamedParameter($room->getId(), IQueryBuilder::PARAM_INT)));
-		$query->executeStatement();
+		$update = $this->connection->getQueryBuilder();
+		$update->update('talk_attendees')
+			->set('last_read_message', $update->createNamedParameter(0, IQueryBuilder::PARAM_INT))
+			->set('last_mention_message', $update->createNamedParameter(0, IQueryBuilder::PARAM_INT))
+			->set('last_mention_direct', $update->createNamedParameter(0, IQueryBuilder::PARAM_INT))
+			->where($update->expr()->eq('room_id', $update->createNamedParameter($room->getId(), IQueryBuilder::PARAM_INT)));
+		$update->executeStatement();
 	}
 
 	public function updateReadPrivacyForActor(string $actorType, string $actorId, int $readPrivacy): void {
-		$query = $this->connection->getQueryBuilder();
-		$query->update('talk_attendees')
-			->set('read_privacy', $query->createNamedParameter($readPrivacy, IQueryBuilder::PARAM_INT))
-			->where($query->expr()->eq('actor_type', $query->createNamedParameter($actorType)))
-			->andWhere($query->expr()->eq('actor_id', $query->createNamedParameter($actorId)));
-		$query->execute();
+		$update = $this->connection->getQueryBuilder();
+		$update->update('talk_attendees')
+			->set('read_privacy', $update->createNamedParameter($readPrivacy, IQueryBuilder::PARAM_INT))
+			->where($update->expr()->eq('actor_type', $update->createNamedParameter($actorType)))
+			->andWhere($update->expr()->eq('actor_id', $update->createNamedParameter($actorId)));
+		$update->executeStatement();
 	}
 
 	public function updateDisplayNameForActor(string $actorType, string $actorId, string $displayName): void {
-		$query = $this->connection->getQueryBuilder();
-		$query->update('talk_attendees')
-			->set('display_name', $query->createNamedParameter($displayName))
-			->where($query->expr()->eq('actor_type', $query->createNamedParameter($actorType)))
-			->andWhere($query->expr()->eq('actor_id', $query->createNamedParameter($actorId)));
-		$query->execute();
+		$update = $this->connection->getQueryBuilder();
+		$update->update('talk_attendees')
+			->set('display_name', $update->createNamedParameter($displayName))
+			->where($update->expr()->eq('actor_type', $update->createNamedParameter($actorType)))
+			->andWhere($update->expr()->eq('actor_id', $update->createNamedParameter($actorId)));
+		$update->executeStatement();
 	}
 
 	public function getLastCommonReadChatMessage(Room $room): int {
@@ -847,7 +1051,7 @@ class ParticipantService {
 			->andWhere($query->expr()->eq('room_id', $query->createNamedParameter($room->getId(), IQueryBuilder::PARAM_INT)))
 			->andWhere($query->expr()->eq('read_privacy', $query->createNamedParameter(Participant::PRIVACY_PUBLIC, IQueryBuilder::PARAM_INT)));
 
-		$result = $query->execute();
+		$result = $query->executeQuery();
 		$row = $result->fetch();
 		$result->closeCursor();
 
@@ -870,7 +1074,7 @@ class ParticipantService {
 			->groupBy('room_id');
 
 		$commonReads = array_fill_keys($roomIds, 0);
-		$result = $query->execute();
+		$result = $query->executeQuery();
 		while ($row = $result->fetch()) {
 			$commonReads[(int) $row['room_id']] = (int) $row['last_common_read_message'];
 		}
@@ -1001,7 +1205,7 @@ class ParticipantService {
 	 */
 	protected function getParticipantsFromQuery(IQueryBuilder $query, Room $room): array {
 		$participants = [];
-		$result = $query->execute();
+		$result = $query->executeQuery();
 		while ($row = $result->fetch()) {
 			$attendee = $this->attendeeMapper->createAttendeeFromRow($row);
 			if (isset($row['s_id'])) {
@@ -1052,7 +1256,7 @@ class ParticipantService {
 	 * @param Room $room
 	 * @return string[]
 	 */
-	public function getParticipantUserIdsNotInCall(Room $room): array {
+	public function getParticipantUserIdsForCallNotifications(Room $room): array {
 		$query = $this->connection->getQueryBuilder();
 
 		$query->select('a.actor_id')
@@ -1062,14 +1266,16 @@ class ParticipantService {
 				$query->expr()->andX(
 					$query->expr()->eq('s.attendee_id', 'a.id'),
 					$query->expr()->neq('s.in_call', $query->createNamedParameter(Participant::FLAG_DISCONNECTED)),
+					$query->expr()->gte('s.last_ping', $query->createNamedParameter($this->timeFactory->getTime() - Session::SESSION_TIMEOUT, IQueryBuilder::PARAM_INT)),
 				)
 			)
 			->where($query->expr()->eq('a.room_id', $query->createNamedParameter($room->getId(), IQueryBuilder::PARAM_INT)))
 			->andWhere($query->expr()->eq('a.actor_type', $query->createNamedParameter(Attendee::ACTOR_USERS)))
+			->andWhere($query->expr()->eq('a.notification_calls', $query->createNamedParameter(Participant::NOTIFY_CALLS_ON)))
 			->andWhere($query->expr()->isNull('s.in_call'));
 
 		$userIds = [];
-		$result = $query->execute();
+		$result = $query->executeQuery();
 		while ($row = $result->fetch()) {
 			$userIds[] = $row['actor_id'];
 		}
@@ -1128,7 +1334,7 @@ class ParticipantService {
 			->where($query->expr()->eq('a.room_id', $query->createNamedParameter($room->getId(), IQueryBuilder::PARAM_INT)))
 			->andWhere($query->expr()->isNotNull('s.id'))
 			->setMaxResults(1);
-		$result = $query->execute();
+		$result = $query->executeQuery();
 		$row = $result->fetch();
 		$result->closeCursor();
 
@@ -1149,8 +1355,9 @@ class ParticipantService {
 			->where($query->expr()->eq('a.room_id', $query->createNamedParameter($room->getId(), IQueryBuilder::PARAM_INT)))
 			->andWhere($query->expr()->isNotNull('s.in_call'))
 			->andWhere($query->expr()->neq('s.in_call', $query->createNamedParameter(Participant::FLAG_DISCONNECTED)))
+			->andWhere($query->expr()->gte('s.last_ping', $query->createNamedParameter($this->timeFactory->getTime() - Session::SESSION_TIMEOUT, IQueryBuilder::PARAM_INT)))
 			->setMaxResults(1);
-		$result = $query->execute();
+		$result = $query->executeQuery();
 		$row = $result->fetch();
 		$result->closeCursor();
 
