@@ -93,7 +93,7 @@ class ShareAPIController {
 			// so the avatars for conversations are distinguishable
 			$result['share_with'] = 'private_conversation_' . substr(sha1($room->getName() . $room->getId()), 0, 6);
 		}
-		if ($room->getType() === Room::PUBLIC_CALL) {
+		if ($room->getType() === Room::TYPE_PUBLIC) {
 			$result['token'] = $share->getToken();
 		}
 		$result['share_with_link'] = $this->urlGenerator->linkToRouteAbsolute('spreed.Page.showCall', ['token' => $room->getToken()]);
