@@ -49,11 +49,6 @@ trait TInitialState {
 		// Needed to enable the screensharing extension in Chromium < 72.
 		Util::addHeader('meta', ['id' => 'app', 'class' => 'nc-enable-screensharing-extension']);
 
-		$this->initialState->provideInitialState(
-			'prefer_h264',
-			$this->serverConfig->getAppValue('spreed', 'prefer_h264', 'no') === 'yes'
-		);
-
 		$signalingMode = $this->talkConfig->getSignalingMode();
 		if ($signalingMode === Config::SIGNALING_CLUSTER_CONVERSATION
 			&& !$this->memcacheFactory->isAvailable()
@@ -72,6 +67,21 @@ trait TInitialState {
 			'sip_dialin_info',
 			$this->talkConfig->getDialInInfo()
 		);
+
+		$this->initialState->provideInitialState(
+			'grid_videos_limit',
+			$this->talkConfig->getGridVideosLimit()
+		);
+
+		$this->initialState->provideInitialState(
+			'grid_videos_limit_enforced',
+			$this->talkConfig->getGridVideosLimitEnforced()
+		);
+
+		$this->initialState->provideInitialState(
+			'federation_enabled',
+			$this->talkConfig->isFederationEnabled()
+		);
 	}
 
 	protected function publishInitialStateForUser(IUser $user, IRootFolder $rootFolder, IAppManager $appManager): void {
